@@ -15,7 +15,8 @@ def dataset_group():
 @dataset_group.command()
 @click.option('-n', '--name', prompt=messages.DATASET_PROMPT_CLONE, help=messages.DATASET_HELP_CLONE)
 @click.option('-o', '--override', is_flag=True, default=False, help=messages.DATASET_HELP_CLONE_OVERRIDE)
-@click.option('-c', '--commit', prompt=messages.DATASET_PROMPT_COMMIT, default=None, help=messages.DATASET_HELP_CLONE_COMMIT)
+@click.option('-c', '--commit', prompt=messages.DATA_PROMPT_COMMIT, default="latest", show_default=True,
+              help=messages.DATASET_HELP_CLONE_COMMIT)
 @prepare_command()
 def clone(cnvrg, logger, name, override, commit):
     """
