@@ -38,7 +38,8 @@ def create(cnvrg, logger, name):
 @project_group.command()
 @click.option('-n', '--name', prompt=messages.PROJECT_PROMPT_CLONE, help=messages.PROJECT_PROMPT_CLONE)
 @click.option('-o', '--override', is_flag=True, default=False, help=messages.PROJECT_HELP_CLONE_OVERRIDE)
-@click.option('-c', '--commit', prompt=messages.PROJECT_PROMPT_COMMIT, default=None, help=messages.PROJECT_HELP_CLONE_COMMIT)
+@click.option('-c', '--commit', prompt=messages.DATA_PROMPT_COMMIT, default="latest",
+              help=messages.PROJECT_HELP_CLONE_COMMIT)
 @prepare_command()
 def clone(cnvrg, logger, name, override, commit):
     """
