@@ -22,11 +22,11 @@ DATA_UPLOAD_SUCCESS = "Successfully uploaded updated files"
 DATA_DOWNLOAD_SUCCESS = "Successfully downloaded updated files"
 DATA_COMMIT_MESSAGE = "Commit message"
 DATA_UPLOAD_HELP_GIT_DIFF = "From the list of files, upload those who returned from git diff command."
+DATA_PROMPT_COMMIT = "Please enter sha1 to clone"
 
 
 # DATASET
 DATASET_PROMPT_CLONE = "Please enter dataset name to clone"
-DATASET_PROMPT_COMMIT = "Please enter sha1 to clone, default is latest"
 DATASET_HELP_CLONE = "Name of the dataset to clone"
 DATASET_HELP_CLONE_OVERRIDE = "Whether or not re-clone in case the dataset already cloned"
 DATASET_HELP_CLONE_COMMIT = "The commit sha1 to clone"
@@ -45,7 +45,6 @@ DATASET_REMOVE_SUCCESS = "Files removed successfully"
 
 # PROJECT
 PROJECT_PROMPT_CLONE = "Please enter project name to clone"
-PROJECT_PROMPT_COMMIT = "Please enter sha1 to clone, default is latest"
 PROJECT_HELP_CLONE = "Name of the project to clone"
 PROJECT_HELP_CLONE_OVERRIDE = "Whether or not re-clone in case the project already cloned"
 PROJECT_HELP_CLONE_COMMIT = "The commit sha1 to clone"
