@@ -45,6 +45,9 @@ COMMIT_FAULTY_SHA1 = "Commit sha1 must be a string"
 PROJECT_GET_FAULTY_SLUG = "Cannot get project with empty slug or a non string slug"
 PROJECT_CREATE_FAULTY_NAME = "Cannot create project with empty/non-string name"
 
+# LIBRARY
+LIBRARY_GET_FAULTY_SLUG = "Cannot get library with empty slug or a non string slug"
+
 # DATASET
 DATASET_GET_FAULTY_SLUG = "Cannot get dataset with empty slug or a non string slug"
 DATASET_CREATE_FAULTY_NAME = "Cannot create dataset with empty/non-string name"
@@ -123,6 +126,7 @@ NOT_LIST = "{} is not a list"
 INVALID_CRON_ARGUMENT = "{0} must be a number between {1} and {2}"
 FILE_TOTAL = "File total is mandatory for azure callback. Please provide a mutable counter - list containing zero [0]"
 NOT_SUPPORTED = "{} are not supported"
+SECRETS_NOT_SUPPORTED = "{} are not supported, use update_secret or delete_secret methods"
 
 # CLI - CONFIG FILE
 CONFIG_FILE_MISSING = "Config file doesn't exist."
