@@ -1,11 +1,12 @@
 import os
+
 import requests
 
+from cnvrgv2.config import CONFIG_VERSION, Config
 from cnvrgv2.config import error_messages, routes
-from cnvrgv2.errors import CnvrgError, CnvrgArgumentsError, CnvrgHttpError
-from cnvrgv2.config import Config, CONFIG_VERSION
+from cnvrgv2.errors import CnvrgArgumentsError, CnvrgError, CnvrgHttpError
 from cnvrgv2.modules.users.users_client import UsersClient
-from cnvrgv2.proxy import Proxy, HTTP
+from cnvrgv2.proxy import HTTP, Proxy
 
 
 class SCOPE:
@@ -92,7 +93,10 @@ class SCOPE:
 
 
 class Context:
-    def __init__(self, context=None, domain=None, user=None, password=None, organization=None, token=None, is_capi=True):
+    def __init__(
+            self, context=None, domain=None, user=None, password=None, organization=None, token=None,
+            is_capi=True
+            ):
         # Set the credentials variables:
         self.token = None
         self.domain = None
