@@ -1,12 +1,14 @@
 import mimetypes
 import os
+
 import google.auth.transport.requests as tr_requests
 from google.oauth2 import service_account
 from google.resumable_media.requests import ChunkedDownload, ResumableUpload
-from cnvrgv2.utils.retry import retry
+
 from cnvrgv2.config import CONFIG_FOLDER_NAME
-from cnvrgv2.utils.storage_utils import download_file, create_dir_if_not_exists
 from cnvrgv2.data.clients.base_storage_client import BaseStorageClient
+from cnvrgv2.utils.retry import retry
+from cnvrgv2.utils.storage_utils import create_dir_if_not_exists, download_file
 
 
 class GCPStorage(BaseStorageClient):
@@ -16,12 +18,12 @@ class GCPStorage(BaseStorageClient):
 
         self.key_file = os.path.join(os.path.expanduser("~"), CONFIG_FOLDER_NAME, ".gcp_cred.json")
 
-        props = self._decrypt_dict(storage_meta, keys=["credentials"])
+        self.props = self._decrypt_dict(storage_meta, keys=["credentials", "bucket_name", "project_id"])
 
-        download_file(props["credentials"], self.key_file)
+        download_file(self.props["credentials"], self.key_file)
 
-        self.download_url_template = 'https://storage.googleapis.com/cnvrg-storage/{object_path}'
-        self.upload_url = 'https://www.googleapis.com/upload/storage/v1/b/cnvrg-storage/o/?uploadType=resumable'
+        self.download_url_template = 'https://storage.googleapis.com/{bucket_name}/{object_path}'
+        self.upload_url = 'https://www.googleapis.com/upload/storage/v1/b/{bucket_name}/o/?uploadType=resumable'
         self.credential_scope = 'https://www.googleapis.com/auth/devstorage.read_write'
         self.transport = self._get_transport()
 
@@ -31,7 +33,7 @@ class GCPStorage(BaseStorageClient):
             progress_incrementer = self.progress_callback(progress_bar)
             metadata = {'name': object_path}
             content_type = mimetypes.guess_type(local_path, strict=True)[0] or "plain/text"
-            media_url = self.upload_url.format(object_path=object_path)
+            media_url = self.upload_url.format(object_path=object_path, bucket_name=self.props['bucket_name'])
 
             with open(local_path, "rb") as file_stream:
                 # Creates a ResumableUpload object that allows to transmit data in chunks.
@@ -52,7 +54,10 @@ class GCPStorage(BaseStorageClient):
     def download_single_file(self, local_path, object_path, progress_bar=None):
         try:
             progress_incrementer = self.progress_callback(progress_bar)
-            media_url = self.download_url_template.format(object_path=object_path)
+            media_url = self.download_url_template.format(
+                object_path=object_path,
+                bucket_name=self.props['bucket_name']
+            )
             create_dir_if_not_exists(local_path)
             with open(local_path, "wb") as file_stream:
                 download = ChunkedDownload(media_url, self.chunk_size, file_stream)
