@@ -212,6 +212,9 @@ class LocalFilesHandler:
             except Empty:
                 time.sleep(0.5)
 
+        if len(uploaded_ids) > 0:
+            self._handle_file_progress_function(uploaded_ids)
+
         self.clear()
 
     def _handle_file_progress_function(self, uploaded_ids):
