@@ -356,7 +356,6 @@ class DataOwner(DynamicAttributes):
         @param commit: [String] sha1 of the commit to clone
         @return: None
         """
-
         self.reload()
 
         if not os.path.exists(self.slug):
@@ -365,7 +364,7 @@ class DataOwner(DynamicAttributes):
             # If already cloned and override set to false - won't clone again
             return
 
-        if commit:
+        if commit and commit.lower() != 'latest':
             self.last_commit = commit
 
         old_working_dir = self.working_dir
@@ -381,7 +380,6 @@ class DataOwner(DynamicAttributes):
                 os.rmdir(self.slug)
             raise CnvrgError(downloader.errors.args)
 
-
         self.local_commit = self.last_commit
         self.save_config(local_config_path=self.working_dir + '/' + CONFIG_FOLDER_NAME)
 
