@@ -163,11 +163,12 @@ class Experiment(WorkflowInstanceBase):
         commit_msg = "Log Images Commit"
         self.put_files(file_paths, message=commit_msg, job_slug=self.slug, tag_images=True)
 
-    def log_artifacts(self, paths=None, git_diff=False):
+    def log_artifacts(self, paths=None, git_diff=False, work_dir=None):
         """
         Saves the given artifacts to the current experiment as a new commit
         @param paths: list of paths of artifacts to save
         @param git_diff: upload files from git diff output in addition to the given paths
+        @param work_dir: working directory param
         @return: None
         """
         if not paths and not git_diff:
@@ -175,6 +176,9 @@ class Experiment(WorkflowInstanceBase):
         if not isinstance(paths, list):
             raise CnvrgArgumentsError(NOT_LIST.format("paths"))
 
+        if work_dir:
+            self.working_dir = work_dir
+
         commit_msg = "Log Artifacts Commit"
         self.put_files(paths, message=commit_msg, job_slug=self.slug, git_diff=git_diff)
         self.reload()
